[CORD-2031] Migration of vHSS service to 4.1

Change-Id: Iaab41b6cbfa8fb5036ae04bb9f30f3a55bcdbd1e
(cherry picked from commit c8c6ddd43f0657c2146ac4a8b5ff03141b6375db)
diff --git a/xos/synchronizer/vhss-synchronizer.py b/xos/synchronizer/vhss-synchronizer.py
index bae8953..2d1bb00 100755
--- a/xos/synchronizer/vhss-synchronizer.py
+++ b/xos/synchronizer/vhss-synchronizer.py
@@ -14,15 +14,18 @@
 
 #!/usr/bin/env python
 
 # Runs the standard XOS synchronizer
 
 import importlib
 import os
 import sys
 
-synchronizer_path = os.path.join(os.path.dirname(
-    os.path.realpath(__file__)), "../../synchronizers/new_base")
-sys.path.append(synchronizer_path)
+from xosconfig import Config
+config_file = os.path.abspath(os.path.dirname(os.path.realpath(__file__)) + '/vhss_config.yaml')
+
+Config.init(config_file, 'synchronizer-config-schema.yaml')
+observer_path = os.path.join(os.path.dirname(os.path.realpath(__file__)), "../../synchronizers/new_base")
+
+sys.path.append(observer_path)
 mod = importlib.import_module("xos-synchronizer")
 mod.main()
-
@@ -14,15 +14,18 @@
 #!/usr/bin/env python
 
-# Runs the standard XOS synchronizer
+# This imports and runs ../../xos-observer.py
 
 import importlib